@@ -138,7 +138,7 @@ OTRS::OPM::Analyzer::Role::Dependencies - Check that all dependencies were decla
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -146,6 +146,12 @@ This role checks if all dependencies were declared. To achieve this, all modules
 C<use>d are compared to the modules OTRS ships and those that are shipped with the Perl
 core.
 
+=head1 METHODS
+
+=head2 check
+
+See I<DESCRIPTION>
+
 =head1 AUTHOR
 
 Renee Baecker <reneeb@cpan.org>
