@@ -81,12 +81,18 @@ OTRS::OPM::Analyzer::Role::SystemCall - check if the code does a system call
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
 It might be bad when OTRS add ons calls a third party program. Hence we check for it.
 
+=head1 METHODS
+
+=head2 check
+
+See I<DESCRIPTION>
+
 =head1 AUTHOR
 
 Renee Baecker <reneeb@cpan.org>
